#R code to create a set of small multiple maps using data from the Guardian's "Gay rights in the United States" visualization. Code provided by PolicyViz.com
library(tidyverse)
library(forcats)
library(geofacet)
library(gridExtra)
library(rgdal)
library(broom)
library(tigris)
library(readxl)
library("xlsx")
library(urbnmapr)
library(sf)
library(gridExtra)

mapbins <- read_excel("RadialMapData.xlsx", sheet="GuardianData",range="A1:H52")

us_states <- get_urbn_map("states", sf = TRUE)
us_states_join <- left_join(us_states, mapbins,by=c("state_name"="State"))

#Drop DC (not in shapefile)
us_states_join <- drop_na(us_states_join, "Marriage")

us_states_join <- rename(us_states_join,
                         marriage = "Marriage",
                         hospital = "Hospital",
                         adoption = "Adoption",
                         employment = "Employment",
                         housing = "Housing",
                         crimes = "Crimes",
                         schools = "Schools")

theme_map <- function(base_size=9, base_family="") {
  require(grid)
  theme_bw(base_size=base_size, base_family=base_family) %+replace%
    theme(axis.line=element_blank(),
          axis.text=element_blank(),
          axis.ticks=element_blank(),
          axis.title=element_blank(),
          panel.background=element_blank(),
          panel.border=element_blank(),
          panel.grid=element_blank(),
          panel.spacing=unit(0, "lines"),
          plot.background=element_blank(),
          #legend.justification = c(0,0),
          legend.position = "none"
    )
}

g1 <- ggplot(data = us_states_join) + 
  geom_sf(mapping = aes(fill = factor(marriage)), color="white", lwd=.2) +
  #coord_sf(crs=5070) +
  scale_fill_manual(values=c(rgb(188,27,30,maxColorValue=255), 
                             rgb(234,234,234,maxColorValue=255))) +
  labs(title = "Marriage", fill = NULL) +
  theme_map()
g1

g2 <- ggplot(data = us_states_join) + 
  geom_sf(mapping = aes(fill = factor(hospital)), color="white", lwd=.2) +
  #coord_sf(crs=5070) +
  scale_fill_manual(values=c(rgb(235, 176, 69,maxColorValue=255), 
                             rgb(234,234,234,maxColorValue=255))) +
  labs(title = "Hospital Visits", fill = NULL) +
  theme_map()
g2

g3 <- ggplot(data = us_states_join) + 
  geom_sf(mapping = aes(fill = factor(adoption)), color="white", lwd=.2) +
  #coord_sf(crs=5070) +
  scale_fill_manual(values=c(rgb(9,76,48,maxColorValue=255), 
                             rgb(234,234,234,maxColorValue=255))) +
  labs(title = "Adoption", fill = NULL) +
  theme_map()
g3

g4 <- ggplot(data = us_states_join) + 
  geom_sf(mapping = aes(fill = factor(employment)), color="white", lwd=.2) +
  #coord_sf(crs=5070) +
  scale_fill_manual(values=c(rgb(118,175,49,maxColorValue=255), 
                             rgb(234,234,234,maxColorValue=255))) +
  labs(title = "Employment", fill = NULL) +
  theme_map()
g4

g5 <- ggplot(data = us_states_join) + 
  geom_sf(mapping = aes(fill = factor(housing)), color="white", lwd=.2) +
  #coord_sf(crs=5070) +
  scale_fill_manual(values=c(rgb(194,0,120,maxColorValue=255), 
                             rgb(234,234,234,maxColorValue=255))) +
  labs(title = "Housing", fill = NULL) +
  theme_map()
g5

g6 <- ggplot(data = us_states_join) + 
  geom_sf(mapping = aes(fill = factor(crimes)), color="white", lwd=.2) +
  #coord_sf(crs=5070) +
  scale_fill_manual(values=c(rgb(110,39,135,maxColorValue=255), 
                             rgb(234,234,234,maxColorValue=255))) +
  labs(title = "Hate Crimes", fill = NULL) +
  theme_map()
g6

g7 <- ggplot(data = us_states_join) + 
  geom_sf(mapping = aes(fill = factor(schools)), color="white", lwd=.2) +
  #coord_sf(crs=5070) +
  scale_fill_manual(values=c(rgb(110,181,227,maxColorValue=255), 
                             rgb(234,234,234,maxColorValue=255))) +
  labs(title = "Schools", fill = NULL) +
  theme_map()
g7

#Save file
grid.arrange(g1, g2, g3, g4, g5, g6, g7, nrow=3)
ggsave <- ggplot2::ggsave; body(ggsave) <- body(ggplot2::ggsave)[-2]
g <- arrangeGrob(g1, g2, g3, g4, g5, g6, g7, nrow=3) #generates g
ggsave(file="seven-pack.png", g) #saves g




